#!/usr/bin/env python3 

from pysdb3.mainapp import main as PysdbApp

PysdbApp()

# set tags
        # for row in self.tagged:
        #     item = QtGui.QListWidgetItem()
        #     cb = QtGui.QCheckBox(row[1])
        #     cb.setTristate(True)
        #     cb.setCheckState(row[2])
        #     item.setSizeHint(cb.sizeHint())
        #     self.ui.taggedList.addItem(item)
        #     self.ui.taggedList.setItemWidget(item, cb)
