# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'pysdb3/ui/addeditstructure.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_DialogAddEditStructure(object):
    def setupUi(self, DialogAddEditStructure):
        DialogAddEditStructure.setObjectName("DialogAddEditStructure")
        DialogAddEditStructure.setWindowModality(QtCore.Qt.ApplicationModal)
        DialogAddEditStructure.resize(260, 220)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(DialogAddEditStructure)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setObjectName("formLayout")
        self.label = QtWidgets.QLabel(DialogAddEditStructure)
        self.label.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label.setObjectName("label")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label)
        self.structnameEdit = QtWidgets.QLineEdit(DialogAddEditStructure)
        self.structnameEdit.setObjectName("structnameEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.structnameEdit)
        self.label_2 = QtWidgets.QLabel(DialogAddEditStructure)
        self.label_2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_2.setObjectName("label_2")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_2)
        self.scodeEdit = QtWidgets.QLineEdit(DialogAddEditStructure)
        self.scodeEdit.setObjectName("scodeEdit")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.scodeEdit)
        self.label_3 = QtWidgets.QLabel(DialogAddEditStructure)
        self.label_3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_3.setObjectName("label_3")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_3)
        self.gcodeEdit = QtWidgets.QLineEdit(DialogAddEditStructure)
        self.gcodeEdit.setObjectName("gcodeEdit")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.gcodeEdit)
        self.horizontalLayout_2.addLayout(self.formLayout)
        self.groupBox = QtWidgets.QGroupBox(DialogAddEditStructure)
        self.groupBox.setTitle("")
        self.groupBox.setFlat(False)
        self.groupBox.setCheckable(False)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_2.setContentsMargins(4, 0, 0, 4)
        self.verticalLayout_2.setSpacing(0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.radioPlanar = QtWidgets.QRadioButton(self.groupBox)
        self.radioPlanar.setChecked(True)
        self.radioPlanar.setObjectName("radioPlanar")
        self.verticalLayout_2.addWidget(self.radioPlanar)
        self.radioLinear = QtWidgets.QRadioButton(self.groupBox)
        self.radioLinear.setObjectName("radioLinear")
        self.verticalLayout_2.addWidget(self.radioLinear)
        self.horizontalLayout_2.addWidget(self.groupBox)
        self.verticalLayout_3.addLayout(self.horizontalLayout_2)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.label_5 = QtWidgets.QLabel(DialogAddEditStructure)
        self.label_5.setObjectName("label_5")
        self.verticalLayout.addWidget(self.label_5)
        self.descriptionEdit = QtWidgets.QPlainTextEdit(DialogAddEditStructure)
        self.descriptionEdit.setObjectName("descriptionEdit")
        self.verticalLayout.addWidget(self.descriptionEdit)
        self.verticalLayout_3.addLayout(self.verticalLayout)
        self.buttonBox = QtWidgets.QDialogButtonBox(DialogAddEditStructure)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout_3.addWidget(self.buttonBox)
        self.label.setBuddy(self.structnameEdit)
        self.label_2.setBuddy(self.scodeEdit)
        self.label_3.setBuddy(self.gcodeEdit)
        self.label_5.setBuddy(self.descriptionEdit)

        self.retranslateUi(DialogAddEditStructure)
        self.buttonBox.accepted.connect(DialogAddEditStructure.accept) # type: ignore
        self.buttonBox.rejected.connect(DialogAddEditStructure.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(DialogAddEditStructure)
        DialogAddEditStructure.setTabOrder(self.structnameEdit, self.scodeEdit)
        DialogAddEditStructure.setTabOrder(self.scodeEdit, self.gcodeEdit)
        DialogAddEditStructure.setTabOrder(self.gcodeEdit, self.buttonBox)
        DialogAddEditStructure.setTabOrder(self.buttonBox, self.descriptionEdit)

    def retranslateUi(self, DialogAddEditStructure):
        _translate = QtCore.QCoreApplication.translate
        DialogAddEditStructure.setWindowTitle(_translate("DialogAddEditStructure", "Add site"))
        self.label.setText(_translate("DialogAddEditStructure", "&Structure:"))
        self.label_2.setText(_translate("DialogAddEditStructure", "Structcode:"))
        self.label_3.setText(_translate("DialogAddEditStructure", "Groupcode:"))
        self.radioPlanar.setText(_translate("DialogAddEditStructure", "Planar"))
        self.radioLinear.setText(_translate("DialogAddEditStructure", "Linear"))
        self.label_5.setText(_translate("DialogAddEditStructure", "&Description:"))
