# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'pysdb3/ui/importsitesfile.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_DialogImportSitesFile(object):
    def setupUi(self, DialogImportSitesFile):
        DialogImportSitesFile.setObjectName("DialogImportSitesFile")
        DialogImportSitesFile.resize(273, 286)
        self.verticalLayout = QtWidgets.QVBoxLayout(DialogImportSitesFile)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(DialogImportSitesFile)
        self.groupBox.setObjectName("groupBox")
        self.formLayout = QtWidgets.QFormLayout(self.groupBox)
        self.formLayout.setObjectName("formLayout")
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setObjectName("label")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label)
        self.siteComboFile = QtWidgets.QComboBox(self.groupBox)
        self.siteComboFile.setObjectName("siteComboFile")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.siteComboFile)
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        self.label_2.setObjectName("label_2")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_2)
        self.lonComboFile = QtWidgets.QComboBox(self.groupBox)
        self.lonComboFile.setObjectName("lonComboFile")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.lonComboFile)
        self.label_3 = QtWidgets.QLabel(self.groupBox)
        self.label_3.setObjectName("label_3")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_3)
        self.latComboFile = QtWidgets.QComboBox(self.groupBox)
        self.latComboFile.setObjectName("latComboFile")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.latComboFile)
        self.verticalLayout.addWidget(self.groupBox)
        self.groupBox_2 = QtWidgets.QGroupBox(DialogImportSitesFile)
        self.groupBox_2.setObjectName("groupBox_2")
        self.formLayout_2 = QtWidgets.QFormLayout(self.groupBox_2)
        self.formLayout_2.setObjectName("formLayout_2")
        self.radioUnitExisting = QtWidgets.QRadioButton(self.groupBox_2)
        self.radioUnitExisting.setChecked(True)
        self.radioUnitExisting.setObjectName("radioUnitExisting")
        self.buttonGroup = QtWidgets.QButtonGroup(DialogImportSitesFile)
        self.buttonGroup.setObjectName("buttonGroup")
        self.buttonGroup.addButton(self.radioUnitExisting)
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.radioUnitExisting)
        self.unitCombo = QtWidgets.QComboBox(self.groupBox_2)
        self.unitCombo.setObjectName("unitCombo")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.unitCombo)
        self.radioUnitFile = QtWidgets.QRadioButton(self.groupBox_2)
        self.radioUnitFile.setObjectName("radioUnitFile")
        self.buttonGroup.addButton(self.radioUnitFile)
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.radioUnitFile)
        self.unitComboFile = QtWidgets.QComboBox(self.groupBox_2)
        self.unitComboFile.setObjectName("unitComboFile")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.unitComboFile)
        self.verticalLayout.addWidget(self.groupBox_2)
        self.buttonBox = QtWidgets.QDialogButtonBox(DialogImportSitesFile)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(DialogImportSitesFile)
        self.buttonBox.accepted.connect(DialogImportSitesFile.accept) # type: ignore
        self.buttonBox.rejected.connect(DialogImportSitesFile.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(DialogImportSitesFile)

    def retranslateUi(self, DialogImportSitesFile):
        _translate = QtCore.QCoreApplication.translate
        DialogImportSitesFile.setWindowTitle(_translate("DialogImportSitesFile", "Import settings"))
        self.groupBox.setTitle(_translate("DialogImportSitesFile", "Site"))
        self.label.setText(_translate("DialogImportSitesFile", "Name:"))
        self.label_2.setText(_translate("DialogImportSitesFile", "X/Longitude:"))
        self.label_3.setText(_translate("DialogImportSitesFile", "Y/Latitude:"))
        self.groupBox_2.setTitle(_translate("DialogImportSitesFile", "Unit"))
        self.radioUnitExisting.setText(_translate("DialogImportSitesFile", "Existing:"))
        self.radioUnitFile.setText(_translate("DialogImportSitesFile", "From file:"))
